
library(tictoc)
library(compiler)

# Disable JIT to call compilation explicitely
enableJIT(0)

# small foo function (returns a vector of 300 numeric values)
source("foo_small.R")

# large foo function (returns a vector of 2030 numeric values)
source("foo.R")

n <- 4000
bb <- runif(n)
cc <- runif(n)
n_rep <- 100

# #######################################################################
# Small function tests

# ### Compilation takes a relatively long time
tic()
    foo_small_compiled <- cmpfun(foo_small)
toc() 

# ### Though the compiled function is 5-10 times faster...
tic()
    for(i in 1:n_rep) a <- foo_small_compiled(bb, cc)
toc()
tic()
    for(i in 1:n_rep) a <- foo_small(bb, cc)
toc()

# ### ...execution time for the compiled function 
# ###  with compilation time added is longer than the execution for the non-compiled function
tic()
foo_small_compiled <- cmpfun(foo_small)
for(i in 1:n_rep) a <- foo_small_compiled(bb, cc)
toc()


# #######################################################################
# The problem is accenuated when a function is longer
# On my machine, the compilation lasted ca. 18 minutes
tic()
    foo_compiled <- cmpfun(foo)
toc() 

tic()
for(i in 1:n_rep) a <- foo_compiled(bb, cc)
toc()

tic()
for(i in 1:n_rep) a <- foo(bb, cc)
toc()
